==> jc-1.4.0.tar.gz: gnu/xml/xpath/Path.h <==
// abstract class gnu.xml.xpath.Path

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 5dda8880693fb6c gnu_xml_xpath_Path
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Pattern

#include "gnu/xml/xpath/Pattern.h"

#ifndef _JC_gnu_xml_xpath_Path_H_
#define _JC_gnu_xml_xpath_Path_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Path$sub_refs	_jc_gnu_xml_xpath_Path$sub_refs;
typedef struct _jc_gnu_xml_xpath_Path$sub_nonrefs	_jc_gnu_xml_xpath_Path$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Path$refs	_jc_gnu_xml_xpath_Path$refs;
typedef struct _jc_gnu_xml_xpath_Path$nonrefs	_jc_gnu_xml_xpath_Path$nonrefs;
typedef struct _jc_gnu_xml_xpath_Path$object	_jc_gnu_xml_xpath_Path$object;

typedef const struct _jc_gnu_xml_xpath_Path$vmethods	_jc_gnu_xml_xpath_Path$vmethods;
typedef const struct _jc_gnu_xml_xpath_Path$vtable	_jc_gnu_xml_xpath_Path$vtable;
typedef const struct _jc_gnu_xml_xpath_Path$vtype	_jc_gnu_xml_xpath_Path$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Path$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_xpath_Path$method$evaluate$a720b7aeb2fb20be(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Path$method_info$evaluate$a720b7aeb2fb20be;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Path$vmethods {
	struct _jc_object	*(*evaluate$a720b7aeb2fb20be)(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_xpath_Path$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_Path$vmethods	gnu_xml_xpath_Path;
};

// Vtype
struct _jc_gnu_xml_xpath_Path$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Path$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Path$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Path$refs {
    _jc_gnu_xml_xpath_Path$sub_refs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Path$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Path$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Path$sub_nonrefs	gnu_xml_xpath_Path;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Path$object {
	_jc_gnu_xml_xpath_Path$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Path$vtype	*vtype;
	_jc_gnu_xml_xpath_Path$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Path$vtype _jc_gnu_xml_xpath_Path$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Path, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Path$class_object;

#endif	/* _JC_gnu_xml_xpath_Path_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Path.h <==
// abstract class gnu.xml.xpath.Path

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 5dda8880693fb6c gnu_xml_xpath_Path
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Pattern

#include "gnu/xml/xpath/Pattern.h"

#ifndef _JC_gnu_xml_xpath_Path_H_
#define _JC_gnu_xml_xpath_Path_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Path$sub_refs	_jc_gnu_xml_xpath_Path$sub_refs;
typedef struct _jc_gnu_xml_xpath_Path$sub_nonrefs	_jc_gnu_xml_xpath_Path$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Path$refs	_jc_gnu_xml_xpath_Path$refs;
typedef struct _jc_gnu_xml_xpath_Path$nonrefs	_jc_gnu_xml_xpath_Path$nonrefs;
typedef struct _jc_gnu_xml_xpath_Path$object	_jc_gnu_xml_xpath_Path$object;

typedef const struct _jc_gnu_xml_xpath_Path$vmethods	_jc_gnu_xml_xpath_Path$vmethods;
typedef const struct _jc_gnu_xml_xpath_Path$vtable	_jc_gnu_xml_xpath_Path$vtable;
typedef const struct _jc_gnu_xml_xpath_Path$vtype	_jc_gnu_xml_xpath_Path$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Path$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_xpath_Path$method$evaluate$a720b7aeb2fb20be(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Path$method_info$evaluate$a720b7aeb2fb20be;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Path$vmethods {
	struct _jc_object	*(*evaluate$a720b7aeb2fb20be)(_jc_env *, struct _jc_gnu_xml_xpath_Path$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_Path$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_Path$vmethods	gnu_xml_xpath_Path;
};

// Vtype
struct _jc_gnu_xml_xpath_Path$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Path$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Path$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Path$refs {
    _jc_gnu_xml_xpath_Path$sub_refs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Path$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Path$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Path$sub_nonrefs	gnu_xml_xpath_Path;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Path$object {
	_jc_gnu_xml_xpath_Path$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Path$vtype	*vtype;
	_jc_gnu_xml_xpath_Path$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Path$vtype _jc_gnu_xml_xpath_Path$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Path, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Path$class_object;

#endif	/* _JC_gnu_xml_xpath_Path_H_ */
